# MONK Framework

A framework for abstracting DFE embedded systems to simplify Unit- and
Integrationtests.

For details, have a look in [the documentation](http://dfe.github.io/MONK/).
Changes will be tested and built in [Travis-CI](https://travis-ci.org/DFE/MONK).
